#!/usr/bin/python
# -*- coding: UTF-8 -*-

############################################################
#                                                          #
#  Utilitaire de configuration des messages pour bacula    #
#  génère le fichier /etc/bacula/eolemsgdefs.pic           #
#  et le fichier /etc/bacula/eolemessages.conf             #
#                                                          #
#  licence CECILL                                          #
#                                                          #
#  Klaas TJEBBES klaas.tjebbes@ac-dijon.fr                 # 
#                                                          #
############################################################

import os
import sys
import getopt
import pickle
from creole import parsedico

class baculamsg:
    def __init__(self):
        self.dfich = '/etc/bacula/eolemsgdefs.pic'
        self.conff = '/etc/bacula/eolemessages.conf'
        self.chargedico()

    def chargedico(self):
        """charge le dictionnaire contenant les informations :
            serveur smtp, adresse mail
        """
        try:
            self.dico = pickle.load(file(self.dfich, 'r'))
        except:
            self.dico = {'mail': '', 'smtp': ''}
        d = parsedico.parse_dico()
        # il pourrait y avoir 'mail' et 'smtp' déjà renseigné dans le dictionnaire eole
        for i in ['nom_domaine_local', 'nom_machine', 'numero_etab']:
            self.dico[i] = d[i]
    					    
    def affiche(self):
        """affiche serveur_smtp;adresse_mail
        rien si vide
        """
        msg = ''
        try:
            if self.dico['smtp'] : msg += '%s;'%self.dico['smtp']
            if self.dico['mail']: msg += '%s'%self.dico['mail']
        except: pass
        print msg
    
    def delmail(self):
        """supprime les données du dictionnaire et vide le fichier /etc/bacula/eolemessages.conf
        """
        self.dico = {'mail': '', 'smtp': ''}
        self.savedico()
        self.applique_conf()
    
    def set_conf(self, mail, smtp):
        """renseigne la configuration
        """
        self.dico['mail'] = mail
        self.dico['smtp'] = smtp
        self.savedico()
        self.applique_conf()

    def savedico(self):
        """enregistre le dictionnaire après modification
        """
        pickle.dump(self.dico,file(self.dfich, 'w'))
    
    def applique_conf(self):
        """Ecrit le fichier de configuration
        """
        # certain mail refuse les expéditeur d'un domaine inconnu (ex : domain.lan)
        # on prend le domaine du premier mail
        if self.dico['mail']:
            try:
                self.dico['expediteur'] = self.dico['mail'].split(',')[0].split('@')[1]
                tmpl ="""mailcommand = "/usr/sbin/bsmtp -h %(smtp)s -f bacula-%(nom_domaine_local)s@%(expediteur)s -s \\"%(numero_etab)s sauvegarde %(nom_machine)s.%(nom_domaine_local)s : %%e\\" %%r"
MailOnError = %(mail)s = all
"""%self.dico
            except: tmpl = ''
        else: tmpl = ''
        file(self.conff, 'w').write(tmpl)
        os.system('echo reload | bconsole -c /etc/bacula/bconsole.conf > /dev/null')

def main():
    bmsg = baculamsg()
    # gestion des options
    mail, servsmtp = '', ''
    try:
        options, args = getopt.getopt(sys.argv[1:],'s:m:dla',
        ['servsmtp=',
        'mail=',
        'delete',
        'liste',
        'applique'])

    except getopt.GetoptError:
        er_type, er_value, er_traceback = sys.exc_info()
        er_msg = str(er_value)
        sys.exit("l'option -%s est inconnue ou nécessite un argument" % er_msg[er_msg.index('-')+1])

    for (opt,val) in options:
        # par quel SMTP envoyer les mails
        if (opt == '-s') or (opt == '--servsmtp'):
            servsmtp = val.strip()
        # à quelle adresse svp ?
        if (opt == '-m') or (opt == '--mail'):
            mail = val.strip()
        if (opt == '-d') or (opt == '--delete'):
            bmsg.delmail()
            return
        #listing
        if (opt == '-l') or (opt == '--liste'):
            bmsg.affiche()
            return
        # application de la configuration
        if (opt == '-a') or (opt == '--applique'):
            bmsg.applique_conf()
            return

    # renseigne le fichier /etc/bacula/eolemessages.conf
    if mail and servsmtp:
        bmsg.set_conf(mail, servsmtp)
        return 0
    else:
        sys.exit("""
        options possibles :
            -s (--servsmtp)
            -m (--mail)
            -d (--delete)
            -l (--liste)
            -a (--applique)
            """)

if __name__ == "__main__":
    main()

